@@ -7,9 +7,9 @@ from ...types import Response
 
 
 def _get_kwargs(
-    token_prefix: str,
     *,
     client: Client,
+    token_prefix: str,
 ) -> Dict[str, Any]:
     url = "{}/users/tokens/delete/{token_prefix}".format(client.base_url, token_prefix=token_prefix)
 
@@ -24,7 +24,7 @@ def _get_kwargs(
     }
 
 
-def _build_response(*, response: httpx.Response) -> Response[Any]:
+def _build_response(*, response: httpx.Response) -> Response[None]:
     return Response(
         status_code=response.status_code,
         content=response.content,
@@ -34,26 +34,16 @@ def _build_response(*, response: httpx.Response) -> Response[Any]:
 
 
 def sync_detailed(
-    token_prefix: str,
     *,
     client: Client,
-) -> Response[Any]:
-    """delete token
-
-    Args:
-        token_prefix (str):
-
-    Returns:
-        Response[Any]
-    """
-
+    token_prefix: str,
+) -> Response[None]:
     kwargs = _get_kwargs(
-        token_prefix=token_prefix,
         client=client,
+        token_prefix=token_prefix,
     )
 
     response = httpx.delete(
-        verify=client.verify_ssl,
         **kwargs,
     )
 
@@ -61,25 +51,16 @@ def sync_detailed(
 
 
 async def asyncio_detailed(
-    token_prefix: str,
     *,
     client: Client,
-) -> Response[Any]:
-    """delete token
-
-    Args:
-        token_prefix (str):
-
-    Returns:
-        Response[Any]
-    """
-
+    token_prefix: str,
+) -> Response[None]:
     kwargs = _get_kwargs(
-        token_prefix=token_prefix,
         client=client,
+        token_prefix=token_prefix,
     )
 
-    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
+    async with httpx.AsyncClient() as _client:
         response = await _client.delete(**kwargs)
 
     return _build_response(response=response)
